@@ -1,8 +1,8 @@
 {-|
 Module      : Lua.LPeg
-Copyright   : © 2021-2022 Albert Krewinkel
+Copyright   : © 2021-2023 Albert Krewinkel
 License     : MIT
-Maintainer  : Albert Krewinkel <tarleb+hslua@zeitkraut.de>
+Maintainer  : Albert Krewinkel <tarleb@hslua.org>
 
 Haskell bindings to the LPeg Lua package.
 -}
